@@ -1,9 +1,9 @@
+#line 2 "edit-distance.h.tmpl"
 #ifndef EDIT_DISTANCE_CHAR_H
 #define EDIT_DISTANCE_CHAR_H
-
-int distance_char (const unsigned char * word1,
-                    int len1,
+#line 1 "declaration"
+int distance_char (
                     text_fuzzy_t * tf)
 ;
-
+#line 7 "edit-distance.h.tmpl"
 #endif /* EDIT_DISTANCE_CHAR_H */
